"""
Deeplabcut Tracking
====================

This module is still under dev, not yet do much systematic testing.

contact author or raise issue if needed soon.

"""
from .core import *
from .util import *



from __future__ import annotations

from neuralib.util.deprecation import deprecated_func

__all__ = ['csv_header']


@deprecated_func(new='neuralib.io.csv_header()', removal_version='0.3.0')
def csv_header(*args, **kwargs):
    from neuralib.io import csv_header
    return csv_header(*args, **kwargs)



__all__ = ['check_attrs_in_clazz']


def check_attrs_in_clazz(cls: type, attr: str) -> bool:
    """
    Check if attr is in the class

    :param cls: class name
    :param attr: attribute name
    :return:
    """
    if attr in getattr(cls, '__annotations__', {}):
        return True

    for c in cls.mro()[1:]:  # Skip the first class as it's already checked
        if attr in getattr(c, '__annotations__', {}):
            return True

    return False
